Agent class

Represents a support agent viewing the cobrowsing session.

Properties

email → String
The email of the support agent, may be null if account privacy settings restrict access to the agent email.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The id of the support agent.
final
name → String
The display name of the support agent.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited