ensureInitialized method

  1. @override
dynamic ensureInitialized()
override

Ensures that the bridge between the Flutter SDK and the native Cobrowse SDK is initialized. Call this in case no other Flutter SDK API is invoked in the Dart part of your app, and if Redacted is not used in your UI.

Implementation

@override
ensureInitialized() {
  // Do nothing. The channels are set up in the constructor.
}